@@ -1,11 +1,17 @@
 import sys
 import time
 from contextlib import ContextDecorator
+from typing import Optional, TYPE_CHECKING, Union
+
+if TYPE_CHECKING:
+    import logging
+    from dimtim.helpers import Logger
 
 
 class timeit(ContextDecorator):
-    def __init__(self, tag: str = '-'):
+    def __init__(self, tag: str = '-', out: Optional[Union['Logger', 'logging.Logger']] = None):
         self.tag = tag
+        self.out = out
 
     def __enter__(self):
         self.start = time.time()
@@ -21,5 +27,9 @@ class timeit(ContextDecorator):
         else:
             formatted = f'{round(duration / 60, 8)} m'
 
-        sys.stdout.write(f'EXECUTION TIME :: {self.tag} :: {formatted}\n')
+        message = f'EXECUTION TIME :: {self.tag} :: {formatted}'
+        if self.out:
+            self.out.debug(message)
+        else:
+            sys.stdout.write(f'{message}\n')
         return False
